==> haskell-fgl-arbitrary-0.2.0.6-183-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-9MSrpjjugC75XDm0ddfwZa
key:                  fgl-arbitrary-0.2.0.6-9MSrpjjugC75XDm0ddfwZa
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  680999ee9fc889004fb082ae957720e4
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl-arbitrary
hs-libraries:         HSfgl-arbitrary-0.2.0.6-9MSrpjjugC75XDm0ddfwZa
depends:
    QuickCheck-2.14.3-KBQtot6OiBttU8xgKWkQ base-4.17.2.1
    fgl-5.8.3.0-IHVaHNCStQgL0FDdxnnM4Y

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-arbitrary-0.2.0.6-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-38mlWdXNeffHT5gqDOR9Hq
key:                  fgl-arbitrary-0.2.0.6-38mlWdXNeffHT5gqDOR9Hq
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  c5685a347e450b955e32552843414929
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl-arbitrary
hs-libraries:         HSfgl-arbitrary-0.2.0.6-38mlWdXNeffHT5gqDOR9Hq
depends:
    QuickCheck-2.14.3-3S3WOBL6rHa3L0CMYI1WVh base-4.17.2.1
    fgl-5.8.3.0-HsH6U127Qzn9oPuAQfABuD

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
